@@ -1,6 +1,6 @@
 package Net::Amazon::S3::ACL::Set;
-# Abstract: Representation of explicit ACL
-$Net::Amazon::S3::ACL::Set::VERSION = '0.98';
+# ABSTRACT: Representation of explicit ACL
+$Net::Amazon::S3::ACL::Set::VERSION = '0.100';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Moose::Util::TypeConstraints;
@@ -124,11 +124,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::ACL::Set
+Net::Amazon::S3::ACL::Set - Representation of explicit ACL
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 SYNOPSIS
 
@@ -198,7 +198,7 @@ instance of C<Net::Amazon::S3::ACL::Grantee::*>.
 		Net::Amazon::S3::ACL::Grantee::Email->new ('foo@bar.baz'),
 	);
 
-=over
+=back
 
 =head1 AUTHOR
 
@@ -214,7 +214,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
