@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Bucket;
 # ABSTRACT: convenience object for working with Amazon S3 buckets
-$Net::Amazon::S3::Bucket::VERSION = '0.98';
+$Net::Amazon::S3::Bucket::VERSION = '0.100';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Carp;
@@ -158,6 +158,7 @@ sub get_key {
 		'Net::Amazon::S3::Operation::Object::Fetch',
 
 		filename => $args{filename},
+		(range   => $args{range}) x defined $args{range},
 
 		key    => $args{key},
 		method => $args{method},
@@ -447,7 +448,7 @@ Net::Amazon::S3::Bucket - convenience object for working with Amazon S3 buckets
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 SYNOPSIS
 
@@ -478,6 +479,9 @@ version 0.98
   is( $val->{etag},                'b9ece18c950afbfa6b0fdbfa4ff731d3' );
   is( $val->{'x-amz-meta-colour'}, 'orange' );
 
+  # fetch a part of the key
+  $val = $bucket->get_key("key", { range => "bytes=1024-10240" });
+
   # returns undef on missing or on error (check $bucket->err)
   is(undef, $bucket->get_key("non-existing-key"));
   die $bucket->errstr if $bucket->err;
@@ -858,7 +862,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
