@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Constants;
-# Abstract: Misc constants used by S3
-$Net::Amazon::S3::Constants::VERSION = '0.98';
+# ABSTRACT: Misc constants used by S3
+$Net::Amazon::S3::Constants::VERSION = '0.100';
 use constant {
 	HEADER_BUCKET_REGION        => 'x-amz-bucket-region',
 	HEADER_CANNED_ACL           => 'x-amz-acl',
@@ -30,11 +30,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Constants
+Net::Amazon::S3::Constants - Misc constants used by S3
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
