@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Operation::Object::Acl::Set::Response;
 # ABSTRACT: An internal class to handle set object acl response
-$Net::Amazon::S3::Operation::Object::Acl::Set::Response::VERSION = '0.98';
+$Net::Amazon::S3::Operation::Object::Acl::Set::Response::VERSION = '0.100';
 use Moose;
 
 extends 'Net::Amazon::S3::Response';
@@ -19,11 +19,11 @@ Net::Amazon::S3::Operation::Object::Acl::Set::Response - An internal class to ha
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 DESCRIPTION
 
-Implements operation L<< PutObjectAcl|https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html>.
+Implements operation L<< PutObjectAcl|https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html >>.
 
 =head1 AUTHOR
 
@@ -31,7 +31,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
