@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Operation::Object::Fetch::Request;
 # ABSTRACT: An internal class to get an object
-$Net::Amazon::S3::Operation::Object::Fetch::Request::VERSION = '0.98';
+$Net::Amazon::S3::Operation::Object::Fetch::Request::VERSION = '0.100';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 
@@ -8,6 +8,20 @@ extends 'Net::Amazon::S3::Request::Object';
 
 with 'Net::Amazon::S3::Request::Role::HTTP::Method';
 
+has 'range'
+	=> is       => 'ro'
+	=> isa      => 'Str'
+	;
+
+override _request_headers => sub {
+	my ($self) = @_;
+
+	return (
+		super,
+		(Range => $self->range) x defined $self->range,
+	);
+};
+
 __PACKAGE__->meta->make_immutable;
 
 sub query_string_authentication_uri {
@@ -35,7 +49,7 @@ Net::Amazon::S3::Operation::Object::Fetch::Request - An internal class to get an
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 SYNOPSIS
 
@@ -70,7 +84,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
