@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::API;
 # ABSTRACT: used for testing and as example
-$Shared::Examples::Net::Amazon::S3::API::VERSION = '0.98';
+$Shared::Examples::Net::Amazon::S3::API::VERSION = '0.100';
 use strict;
 use warnings;
 
@@ -241,7 +241,11 @@ sub operation_object_fetch {
 
 	$self
 		->bucket ($params{with_bucket})
-		->get_key ($params{with_key}, 'GET')
+		->get_key (
+			$params{with_key},
+			'GET',
+			({ range => $params{with_range} }) x exists $params{with_range},
+		)
 		;
 }
 
@@ -313,7 +317,7 @@ Shared::Examples::Net::Amazon::S3::API - used for testing and as example
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 AUTHOR
 
@@ -321,7 +325,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
