@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Client;
 # ABSTRACT: used for testing and as example
-$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.98';
+$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.100';
 use strict;
 use warnings;
 
@@ -201,20 +201,26 @@ sub operation_object_delete {
 sub operation_object_fetch {
 	my ($self, %params) = @_;
 
-	$self
+	my $object = $self
 		->bucket (name => $params{with_bucket})
 		->object (key => $params{with_key})
-		->get
 		;
+
+	$object = $object->range ($params{with_range})
+		if $params{with_range};
+
+	$object->get;
 }
 
 sub operation_object_head {
 	my ($self, %params) = @_;
 
+	my $method = $params{-method} // 'exists';
+
 	$self
 		->bucket (name => $params{with_bucket})
 		->object (key => $params{with_key})
-		->exists
+		->$method
 		;
 }
 
@@ -304,7 +310,7 @@ Shared::Examples::Net::Amazon::S3::Client - used for testing and as example
 
 =head1 VERSION
 
-version 0.98
+version 0.100
 
 =head1 AUTHOR
 
@@ -312,7 +318,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2022 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
